@@ -7,13 +7,23 @@ extends 'Number::MuPhone::Parser';
 
 sub config { 
   return {
+  'internationalPrefix'=>'00',
+  'TerritoryName'=>'Cook Islands',
+  'CountryCode'=>'CK',
+  'references'=>{
+                  'sourceUrl'=>'http://www.itu.int/oth/T020200002F/en'
+                },
+  'countryCode'=>'682',
   'fixedLine'=>{
-                 'exampleNumber'=>'21234',
+                 'nationalNumberPattern'=>'(?:2\\d|3[13-7]|4[1-5])\\d{3}',
                  'possibleLengths'=>{
                                       'national'=>'5'
                                     },
-                 'nationalNumberPattern'=>'(?:2\\d|3[13-7]|4[1-5])\\d{3}'
+                 'exampleNumber'=>'21234'
                },
+  'generalDesc'=>{
+                   'nationalNumberPattern'=>'[2-8]\\d{4}'
+                 },
   'mobile'=>{
               'nationalNumberPattern'=>'[5-8]\\d{4}',
               'possibleLengths'=>{
@@ -21,25 +31,15 @@ sub config {
                                  },
               'exampleNumber'=>'71234'
             },
-  'references'=>{
-                  'sourceUrl'=>'http://www.itu.int/oth/T020200002F/en'
-                },
-  'countryCode'=>'682',
-  'internationalPrefix'=>'00',
-  'CountryCode'=>'CK',
   'availableFormats'=>{
                           'numberFormat'=>[
                                               {
                                                 'leadingDigits'=>'',
-                                                'format'=>'$1 $2',
-                                                'pattern'=>'(\\d{2})(\\d{3})'
+                                                'pattern'=>'(\\d{2})(\\d{3})',
+                                                'format'=>'$1 $2'
                                               }
                                             ]
-                        },
-  'TerritoryName'=>'Cook Islands',
-  'generalDesc'=>{
-                   'nationalNumberPattern'=>'[2-8]\\d{4}'
-                 }
+                        }
 }
 ;
 }
